@@ -8,11 +8,15 @@ from onnx2tf.utils.common_functions import (
     print_node_info,
     inverted_operation_enable_disable,
     make_tf_node_info,
+    get_replacement_parameter,
+    pre_process_transpose,
+    post_process_transpose,
 )
 
 
 @print_node_info
 @inverted_operation_enable_disable
+@get_replacement_parameter
 def make_node(
     *,
     graph_node: gs.Node,
@@ -84,6 +88,15 @@ def make_node(
 
     # Generation of TF OP
     input_tensor = tf_layers_dict[X.name]['tf_node']
+
+    # Pre-process transpose
+    input_tensor = pre_process_transpose(
+        value_before_transpose=input_tensor,
+        param_target='inputs',
+        param_name=graph_node.inputs[0].name,
+        **kwargs,
+    )
+
     tf_layers_dict[Y.name]['tf_node'] = tf.nn.batch_normalization(
         x=input_tensor,
         mean=input_mean.values \
@@ -97,6 +110,14 @@ def make_node(
         variance_epsilon=epsilon,
     )
 
+    # Post-process transpose
+    tf_layers_dict[Y.name]['tf_node'] = post_process_transpose(
+        value_before_transpose=tf_layers_dict[Y.name]['tf_node'],
+        param_target='outputs',
+        param_name=graph_node.outputs[0].name,
+        **kwargs,
+    )
+
     # Generation of Debug Info
     tf_layers_dict[Y.name]['tf_node_info'] = \
         make_tf_node_info(
