@@ -101,12 +101,23 @@ def make_node(
         max_value = max_value_node
 
     # Pre-process transpose
+    before_trans_shape = features.shape
     features = pre_process_transpose(
         value_before_transpose=features,
         param_target='inputs',
         param_name=graph_node.inputs[0].name,
         **kwargs,
     )
+    after_trans_shape = features.shape
+    if 'nhwc' in tf_layers_dict[graph_node_output.name].keys() \
+        and tf_layers_dict[graph_node_output.name]['nhwc'] == True \
+        and before_trans_shape != after_trans_shape:
+        tf_layers_dict[graph_node_output.name].pop('nhwc')
+
+    if min_value is not None and isinstance(min_value, float):
+        min_value = np.asarray([min_value])
+    if max_value is not None and isinstance(max_value, float):
+        max_value = np.asarray([max_value])
 
     tf_op_type = None
     if (isinstance(min_value, np.ndarray) or isinstance(min_value, float)) and min_value == 0.0 \
@@ -147,12 +158,18 @@ def make_node(
             tf_op_type = tf.minimum
 
     # Post-process transpose
+    before_trans_shape = tf_layers_dict[graph_node_output.name]['tf_node'].shape
     tf_layers_dict[graph_node_output.name]['tf_node'] = post_process_transpose(
         value_before_transpose=tf_layers_dict[graph_node_output.name]['tf_node'],
         param_target='outputs',
         param_name=graph_node.outputs[0].name,
         **kwargs,
     )
+    after_trans_shape = tf_layers_dict[graph_node_output.name]['tf_node'].shape
+    if 'nhwc' in tf_layers_dict[graph_node_output.name].keys() \
+        and tf_layers_dict[graph_node_output.name]['nhwc'] == True \
+        and before_trans_shape != after_trans_shape:
+        tf_layers_dict[graph_node_output.name].pop('nhwc')
 
     # Generation of Debug Info
     tf_layers_dict[graph_node_output.name]['tf_node_info'] = \
