@@ -13,7 +13,9 @@ from onnx2tf.utils.common_functions import (
     get_replacement_parameter,
     pre_process_transpose,
     post_process_transpose,
+    transpose_with_flexing_deterrence,
 )
+from onnx2tf.utils.enums import NUMPY_DTYPES_TO_TF_DTYPES
 
 
 @print_node_info
@@ -102,11 +104,18 @@ def make_node(
     if axis != (tensor_rank-1):
         perm = [idx for idx in range(tensor_rank) if idx != axis] + [axis]
         input_tensor = \
-            tf.transpose(
-                a=input_tensor,
+            transpose_with_flexing_deterrence(
+                input_tensor=input_tensor,
                 perm=perm,
+                **kwargs,
             )
 
+    # MLIR only accepts scalar values for k-values, thus compressing the dimension
+    if isinstance(k_tensor, int):
+        pass
+    elif k_tensor.shape is not None and len(k_tensor.shape) >= 1:
+        k_tensor = tf.squeeze(k_tensor)
+
     if largest:
         topked_values, topked_indices = \
             tf.math.top_k(
@@ -124,18 +133,24 @@ def make_node(
                 name=graph_node.name,
             )
         topked_values = tf.negative(topked_values)
+    topked_indices = tf.cast(
+        x=topked_indices,
+        dtype=NUMPY_DTYPES_TO_TF_DTYPES[Indices_dtype],
+    )
 
     if axis != (tensor_rank-1):
         perm = [perm.index(idx) for idx in range(tensor_rank)]
         topked_values = \
-            tf.transpose(
-                a=topked_values,
+            transpose_with_flexing_deterrence(
+                input_tensor=topked_values,
                 perm=perm,
+                **kwargs,
             )
         topked_indices = \
-            tf.transpose(
-                a=topked_indices,
+            transpose_with_flexing_deterrence(
+                input_tensor=topked_indices,
                 perm=perm,
+                **kwargs,
             )
 
     tf_layers_dict[Values.name]['tf_node'] = topked_values
